===
Job
===

The Job object is the abstract base type for other Job objects. The Job object has no explicit constructor. The methods and members of the Job object are common to all objects derived from Job.


Create jobs
-----------

.. automethod:: abaqus.Job.JobMdb.JobMdb.Job

Create queues in Session
------------------------

.. automethod:: abaqus.Job.JobSession.JobSession.Queue


Features of the job
-------------------

Coexecution
~~~~~~~~~~~

.. autoclass:: abaqus.Job.Coexecution.Coexecution
    :members:

    .. autoclasstoc::

Job
~~~

.. autoclass:: abaqus.Job.Job.Job
    :members:

    .. autoclasstoc::

JobFromInputFile
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Job.JobFromInputFile.JobFromInputFile
    :members:

    .. autoclasstoc::

Message
~~~~~~~

.. autoclass:: abaqus.Job.Message.Message
    :members:

    .. autoclasstoc::

MessageArray
~~~~~~~~~~~~

.. autoclass:: abaqus.Job.MessageArray.MessageArray
    :members:

    .. autoclasstoc::

ModelJob
~~~~~~~~

.. autoclass:: abaqus.Job.ModelJob.ModelJob
    :members:

    .. autoclasstoc::

OptimizationProcess
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Job.OptimizationProcess.OptimizationProcess
    :members:

    .. autoclasstoc::

Queue
~~~~~

.. autoclass:: abaqus.Job.Queue.Queue
    :members:
